==> test_tele-0.0.3.31.1-py3-none-any.whl: test_tele/pyrogram/pixiv.py <==
import uuid 
import logging
from pixivpy3 import *
import time

from pyrogram import enums
from pyrogram.types import InputMediaPhoto, InputMediaDocument
from pyrogram.types import (InlineQueryResultArticle, InlineQueryResultPhoto, InlineQueryResultVideo, InlineKeyboardMarkup, 
                            InlineKeyboardButton, InputTextMessageContent, InlineQueryResultAnimation, InputTextMessageContent)

from .utils import IMG_EXT, BOT_CONFIG, not_found_msg

PIXIV_MODE = ['no_ai', 'no_tag', 'novel', 'nsfw', 'safe']

api = AppPixivAPI()
api.auth(refresh_token=BOT_CONFIG.apis.pixiv_refresh_token)


async def image_keyboard(query: str, my_list: list[str]) -> InlineKeyboardMarkup:
    url = my_list['img_urls']['img_original'].split("/img/")[-1]
    buttons = [[
                InlineKeyboardButton("👤🔄",
                                     switch_inline_query_current_chat=f".px id:{my_list['user_id']}"),
                InlineKeyboardButton("🔗🔄",
                                     switch_inline_query_current_chat=f".px {my_list['id']}")
            ],[
                InlineKeyboardButton("💾" ,
                                     callback_data=f"px {url}"),
                InlineKeyboardButton("🔄",
                                     switch_inline_query_current_chat=query),
            ]]
    return InlineKeyboardMarkup(buttons)


async def get_pixiv_list(query: str, offset: int):
    async def search_by_id(id_val):
        if id_val.isdigit():
            return await set_dict_detail(api.illust_detail(int(id_val)))
        else:
            return None

    if query:
        inputs = query.split()
        for val in inputs:
            user_id = None
            detailed_result = await search_by_id(val)
            if detailed_result:
                return detailed_result
            elif 'id:' in val:
                user_id = val.split("id:")[-1]
                return await set_dict_search(api.user_illusts(int(user_id), offset=offset))
    else:
        # Mengatur default query ke 'sangonomiya kokomi'
        query = '珊瑚宮心海'

    return await set_dict_search(api.search_illust(query, offset=offset))


async def set_dict_search(pixiv_json):
    illusts = pixiv_json["illusts"]
    media_posts = []

    for illust in illusts:
        if illust["meta_pages"]:
            img_ori = illust["meta_pages"][0]["image_urls"]["original"]
        else:
            img_ori = illust['meta_single_page']['original_image_url']
            
        images = {
            "img_thumb": illust["image_urls"]["square_medium"],
            "img_sample": illust["image_urls"]["medium"],
            "img_original": img_ori
        }

        media_post = {
            'id': str(illust["id"]),
            'title': illust["title"],
            'user_id': str(illust["user"]["id"]),
            'user_name': illust["user"]["name"],
            'tags': await get_pixiv_tags(illust["tags"]),
            'img_urls': images
        }
        media_posts.append(media_post)

    return media_posts


async def set_dict_detail(pixiv_json):
    illusts = pixiv_json["illust"]
    media_posts = []

    if 'meta_pages' in illusts and illusts['meta_pages']:
        for illust in illusts['meta_pages']:
            images = {
                "img_thumb": illust["image_urls"]["square_medium"],
                "img_sample": illust["image_urls"]["medium"],
                "img_original": illust["image_urls"]["original"]
            }

            media_post = {
                'id': str(illusts["id"]),
                'title': illusts["title"],
                'user_id': str(illusts["user"]["id"]),
                'user_name': illusts["user"]["name"],
                'tags': await get_pixiv_tags(illusts["tags"]),
                'img_urls': images
            }
            media_posts.append(media_post)
    else:
        images['img_original'] = illusts["meta_single_page"]["original_image_url"]
        media_post = {
            'id': str(illusts["id"]),
            'title': illusts["title"],
            'user_id': str(illusts["user"]["id"]),
            'user_name': illusts["user"]["name"],
            'tags': await get_pixiv_tags(illusts["tags"]),
            'img_urls': images
        }
        media_posts.append(media_post)
    return media_posts


async def get_pixiv_tags(tags):
    all_tags = []
    for tag in tags:
        if not tag.translated_name:
            re_tag = f"`{tag.name}`"
        else:
            re_tag = f"`{tag.name}`(`{tag.translated_name}`)"
        all_tags.append(re_tag)
    final_tag = (", ").join(all_tags)
    return final_tag


async def set_pixiv_mode(query: str) -> dict:
    """Setting searching mode"""
    example_query = ".px sangonomiya kokomi loli no_ai no_tag safe"
    current_modes = {}
    query = query.strip().lower().replace(".px", "").lstrip()
    keywords = query.split()

    for keyword in keywords:
        if keyword in PIXIV_MODE:
            current_modes[keyword] = True
            query = query.replace(keyword, '')
        if keyword.isdigit():
            current_modes['illust_detail'] = True
        if 'no_inline' in keyword:
            current_modes['no_inline'] = True
            query = query.replace(keyword, '')
        if 'as_file' in keyword and current_modes.get('no_inline'):
            current_modes['as_file'] = True
            query = query.replace(keyword, '')
        if 'limit:' in keyword and current_modes.get('no_inline'):
            limit = keyword.split('limit:')[-1]
            current_modes['limit'] = limit
            query = query.replace(keyword, '')
        if 'offset:' in keyword and current_modes.get('no_inline'):
            offset = keyword.split('offset:')[-1]
            current_modes['offset'] = offset
            query = query.replace(keyword, '')

    return current_modes, query.strip()


async def create_inline_query_result_photo(my_list, px_mode, query):
    caption = (
        f"**[{my_list['title']}](https://www.pixiv.net/en/artworks/{my_list['id']})**\n"
        f"Artist : [{my_list['user_name']}](https://www.pixiv.net/en/users/{my_list['user_id']})\n"
        f"Tags : {my_list['tags']}"
    )

    if str(my_list['img_urls']['img_sample']).endswith(tuple(IMG_EXT)):
        result = InlineQueryResultPhoto(
            photo_url=my_list['img_urls']['img_sample'],
            thumb_url=my_list['img_urls']['img_thumb'],
            id=str(uuid.uuid4()) + my_list['id'],
            caption=caption if 'no_tag' not in px_mode else '',
            reply_markup=await image_keyboard(query, my_list),
        )
        return result
    return None


async def inline_pixiv(client, inline_query):
    """Show Pixiv artworks"""
    query = inline_query.query
    if not query:
        return

    limit = 30
    offset = inline_query.offset
    pid = int(offset) if offset else 0

    px_mode, keywords = await set_pixiv_mode(query)
    lists = await get_pixiv_list(keywords, pid)
    results = []

    if pid == 0 and not lists:
        return await not_found_msg(client, inline_query)

    if lists:
        try:
            for my_list in lists:
                result = await create_inline_query_result_photo(my_list, px_mode, query)
                if result:
                    results.append(result)

            cache_time = 60
            next_offset = str(pid + limit) if 'illust_detail' not in px_mode else None
            await client.answer_inline_query(
                inline_query.id, 
                results=results, 
                cache_time=cache_time, 
                is_gallery=True, 
                next_offset=next_offset)
        except Exception as err:
            logging.error(err, exc_info=True)
    

async def get_px_file(url):
    return f"https://i.pximg.net/img-original/img/{url}"


# Perlu decorator premium
async def upload_px_batch(app, message):
    query = str(message.text)
    if not query:
        return
    
    start = time.time()
    img_slice = 10
    chat_id = message.chat.id

    px_mode, keywords = await set_pixiv_mode(query + ' no_inline')

    limit = px_mode.get('limit', 30)
    offset = px_mode.get('offset', 0)
    as_file = px_mode.get('as_file', False)

    lists = await get_pixiv_list(keywords, offset)

    if not lists:
        return
    
    await app.send_chat_action(chat_id, enums.ChatAction.UPLOAD_PHOTO)
    logging.warning(f"selesai ambil data: {round(time.time() - start, 2)}")
    try:
        for i in range(0, len(lists), img_slice):
            media_to_send = []
            if i + 10 > limit:
                break

            for list in lists[i:i + 10]:
                if str(list['img_urls']['img_sample']).endswith(tuple(IMG_EXT)):
                    if as_file:
                        media_to_send.append(InputMediaDocument(media=list['img_urls']['img_original']))
                    else:
                        media_to_send.append(InputMediaPhoto(media=list['img_urls']['img_sample']))

            if media_to_send:
                try:
                    await app.send_media_group(chat_id, media_to_send, disable_notification=True)
                except:
                    pass
        
        await app.send_chat_action(chat_id, enums.ChatAction.CANCEL)
        logging.warning(f"akhir : {round(time.time() - start, 2)}")
    except Exception as err:
        logging.error(err, exc_info=True)

==> test_tele-0.0.4.1-py3-none-any.whl: test_tele/pyrogram/pixiv.py <==
import uuid 
import logging

from test_tele.extractors.pixiv import *
from pyrogram.types import (InlineQueryResultArticle, InlineQueryResultPhoto, InlineQueryResultVideo, InlineKeyboardMarkup, 
                            InlineKeyboardButton, InputTextMessageContent, InlineQueryResultAnimation)

from .utils import IMG_EXT, not_found_msg


async def image_keyboard(query: str, my_list: list[str]) -> InlineKeyboardMarkup:
    url = my_list['img_urls']['img_original'].split("/img/")[-1]
    buttons = [[
                InlineKeyboardButton("👤🔄",
                                     switch_inline_query_current_chat=f".px id:{my_list['user_id']}"),
                InlineKeyboardButton("🔗🔄",
                                     switch_inline_query_current_chat=f".px {my_list['id']}")
            ],[
                InlineKeyboardButton("💾" ,
                                     callback_data=f"px {url}"),
                InlineKeyboardButton("🔄",
                                     switch_inline_query_current_chat=query),
            ]]
    return InlineKeyboardMarkup(buttons)


async def create_inline_query_result_photo(my_list, px_mode, query):
    caption = (
        f"**[{my_list['title']}](https://www.pixiv.net/en/artworks/{my_list['id']})**\n"
        f"Artist : [{my_list['user_name']}](https://www.pixiv.net/en/users/{my_list['user_id']})\n"
        f"Tags : {my_list['tags']}"
    )

    sample_img = my_list['img_urls']['img_sample'].replace('540x540_70', '600x1200_90')
    thumb_img = my_list['img_urls']['img_thumb'].replace('540x540_70', '400x250_80')

    if str(my_list['img_urls']['img_sample']).endswith(tuple(IMG_EXT)):
        result = InlineQueryResultPhoto(
            photo_url=sample_img,
            thumb_url=thumb_img,
            id=str(uuid.uuid4()) + my_list['id'],
            caption=caption if 'no_tag' not in px_mode and my_list['title'] != '' else '',
            reply_markup=await image_keyboard(query, my_list),
        )
        return result
    return None


async def inline_pixiv(client, inline_query):
    """Show Pixiv artworks"""
    query = inline_query.query
    if not query:
        return

    limit = 30
    offset = inline_query.offset
    pid = int(offset) if offset else 0

    px_mode, keywords = await clean_up_tags(query, PIXIV_MODE, '.px')
    lists = await get_pixiv_list(keywords, pid, px_mode)
    results = []

    if pid == 0 and not lists:
        return await not_found_msg(client, inline_query)

    if lists:
        try:
            for my_list in lists:
                result = await create_inline_query_result_photo(my_list, px_mode, query)
                if result:
                    results.append(result)

            cache_time = 60
            next_offset = str(pid + limit) if 'illust_detail' not in px_mode else None
            await client.answer_inline_query(
                inline_query.id, 
                results=results, 
                cache_time=cache_time, 
                is_gallery=True, 
                next_offset=next_offset)
        except Exception as err:
            logging.error(err, exc_info=True)
    

async def get_px_file(url):
    return await get_pixiv_file(url)
